@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -1444,7 +1444,7 @@ run_audio_player_using_directory (GError **error)
     GList *file_list = NULL;
     gboolean res;
 
-    for (l = g_list_first (ETCore->ETFileList); l != NULL; l = g_list_next (l))
+    for (l = ETCore->ETFileList; l != NULL; l = g_list_next (l))
     {
         ET_File *etfile = (ET_File *)l->data;
         const gchar *path = ((File_Name *)etfile->FileNameCur->data)->value;
@@ -1727,7 +1727,7 @@ et_application_window_init (EtApplicationWindow *self)
 
     /* Log */
     priv->log_area = et_log_area_new ();
-    gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->log_area, FALSE, TRUE);
+    gtk_paned_pack2 (GTK_PANED (priv->vpaned), priv->log_area, FALSE, FALSE);
 
     /* Horizontal box for Status bar + Progress bar */
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -2107,6 +2107,24 @@ et_application_window_update_et_file_from_ui (EtApplicationWindow *self)
             FileTag = et_application_window_tag_area_create_file_tag (self);
             et_file_tag_copy_other_into (et_file->FileTag->data, FileTag);
             break;
+#ifndef ENABLE_MP3
+        case ID3_TAG:
+#endif
+#ifndef ENABLE_OGG
+        case OGG_TAG:
+#endif
+#ifndef ENABLE_FLAC
+        case FLAC_TAG:
+#endif
+#ifndef ENABLE_MP4
+        case MP4_TAG:
+#endif
+#ifndef ENABLE_WAVPACK
+        case WAVPACK_TAG:
+#endif
+#ifndef ENABLE_OPUS
+        case OPUS_TAG:
+#endif
         case UNKNOWN_TAG:
         default:
             FileTag = et_file_tag_new ();
@@ -2314,6 +2332,28 @@ et_application_window_display_et_file (EtApplicationWindow *self,
             break;
 #endif
         case OFR_FILE:
+#if !defined ENABLE_MP3 && !defined ENABLE_ID3LIB
+        case MP3_FILE:
+        case MP2_FILE:
+#endif
+#ifndef ENABLE_OGG
+        case OGG_FILE:
+#endif
+#ifndef ENABLE_SPEEX
+        case SPEEX_FILE:
+#endif
+#ifndef ENABLE_FLAC
+        case FLAC_FILE:
+#endif
+#ifndef ENABLE_MP4
+        case MP4_FILE:
+#endif
+#ifndef ENABLE_WAVPACK
+        case WAVPACK_FILE:
+#endif
+#ifndef ENABLE_OPUS
+        case OPUS_FILE:
+#endif
         case UNKNOWN_FILE:
         default:
             /* Default displaying. */
@@ -3019,37 +3059,6 @@ et_application_window_quit (EtApplicationWindow *self)
         }
 
     }
-    else if (g_settings_get_boolean (MainSettings, "confirm-quit"))
-    {
-        msgbox = gtk_message_dialog_new (GTK_WINDOW (self),
-                                         GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                         GTK_MESSAGE_QUESTION,
-                                         GTK_BUTTONS_NONE,
-                                         "%s",
-                                         _("Do you really want to quit?"));
-         gtk_dialog_add_buttons (GTK_DIALOG (msgbox), _("_Cancel"),
-                                 GTK_RESPONSE_CANCEL, _("_Quit"),
-                                 GTK_RESPONSE_CLOSE, NULL);
-        gtk_dialog_set_default_response (GTK_DIALOG (msgbox),
-                                         GTK_RESPONSE_CLOSE);
-        gtk_window_set_title (GTK_WINDOW (msgbox), _("Quit"));
-        response = gtk_dialog_run (GTK_DIALOG (msgbox));
-        gtk_widget_destroy (msgbox);
-
-        switch (response)
-        {
-            case GTK_RESPONSE_CLOSE:
-                quit_confirmed (self);
-                break;
-            case GTK_RESPONSE_CANCEL:
-            case GTK_RESPONSE_DELETE_EVENT:
-                return;
-                break;
-            default:
-                g_assert_not_reached ();
-                break;
-        }
-    }
     else
     {
         quit_confirmed (self);
