@@ -22,8 +22,6 @@
 #include "easytag.h"
 
 #include <glib/gi18n.h>
-#include <stdlib.h>
-#include <sys/stat.h>
 #include <unistd.h>
 #include <sys/types.h>
 
@@ -64,8 +62,6 @@ static gint Save_Selected_Files_With_Answer (gboolean force_saving_files);
 static gint Save_List_Of_Files (GList *etfilelist,
                                 gboolean force_saving_files);
 
-static gboolean et_rename_file (const char *old_filepath,
-                                const char *new_filepath, GError **error);
 static GList *read_directory_recursively (GList *file_list,
                                           GFileEnumerator *dir_enumerator,
                                           gboolean recurse);
@@ -95,13 +91,9 @@ void Action_Force_Saving_Selected_Files (void)
  */
 gint Save_All_Files_With_Answer (gboolean force_saving_files)
 {
-    GList *etfilelist;
-
     g_return_val_if_fail (ETCore != NULL && ETCore->ETFileList != NULL, FALSE);
 
-    etfilelist = g_list_first (ETCore->ETFileList);
-
-    return Save_List_Of_Files (etfilelist, force_saving_files);
+    return Save_List_Of_Files (ETCore->ETFileList, force_saving_files);
 }
 
 /*
@@ -717,129 +709,6 @@ Save_File (ET_File *ETFile, gboolean multiple_files,
     return 1;
 }
 
-/*
- * et_rename_file:
- * @old_filepath: path of file to be renamed
- * @new_filepath: path of renamed file
- * @error: a #GError to provide information on errors, or %NULL to ignore
- *
- * Rename @old_filepath to @new_filepath.
- *
- * Returns: %TRUE if the rename was successful, %FALSE otherwise
- */
-static gboolean
-et_rename_file (const char *old_filepath, const char *new_filepath,
-                GError **error)
-{
-    GFile *file_old;
-    GFile *file_new;
-    GFile *file_new_parent;
-
-    g_return_val_if_fail (old_filepath != NULL && new_filepath != NULL, FALSE);
-    g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
-
-    file_old = g_file_new_for_path (old_filepath);
-    file_new = g_file_new_for_path (new_filepath);
-    file_new_parent = g_file_get_parent (file_new);
-
-    if (!g_file_make_directory_with_parents (file_new_parent, NULL, error))
-    {
-        /* Ignore an error if the directory already exists. */
-        if (!g_error_matches (*error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-        {
-            g_object_unref (file_new_parent);
-            goto err;
-        }
-
-        g_clear_error (error);
-    }
-
-    g_assert (error == NULL || *error == NULL);
-    g_object_unref (file_new_parent);
-
-    /* Move the file. */
-    if (!g_file_move (file_old, file_new, G_FILE_COPY_NONE, NULL, NULL, NULL,
-                      error))
-    {
-        if (g_error_matches (*error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-        {
-            /* Possibly a case change on a case-insensitive filesystem. */
-            /* TODO: casefold the paths of both files, and check to see whether
-             * they only differ by case? */
-            gchar *tmp_filename;
-            mode_t old_mode;
-            gint fd;
-            GFile *tmp_file;
-            GError *tmp_error = NULL;
-
-            tmp_filename = g_strconcat (old_filepath, ".XXXXXX", NULL);
-
-            old_mode = umask (077);
-            fd = mkstemp (tmp_filename);
-            umask (old_mode);
-
-            if (fd >= 0)
-            {
-                close (fd);
-            }
-
-            tmp_file = g_file_new_for_path (tmp_filename);
-            g_free (tmp_filename);
-
-            if (!g_file_move (file_old, tmp_file, G_FILE_COPY_OVERWRITE, NULL,
-                              NULL, NULL, &tmp_error))
-            {
-                g_file_delete (tmp_file, NULL, NULL);
-
-                g_object_unref (tmp_file);
-                g_clear_error (error);
-                g_propagate_error (error, tmp_error);
-                goto err;
-            }
-            else
-            {
-                /* Move to temporary file succeeded, now move to the real new
-                 * location. */
-                if (!g_file_move (tmp_file, file_new, G_FILE_COPY_NONE, NULL,
-                                  NULL, NULL, &tmp_error))
-                {
-                    g_file_move (tmp_file, file_old, G_FILE_COPY_NONE, NULL,
-                                 NULL, NULL, NULL);
-                    g_object_unref (tmp_file);
-                    g_clear_error (error);
-                    g_propagate_error (error, tmp_error);
-                    goto err;
-                }
-                else
-                {
-                    /* Move succeeded, so clear the original error about the
-                     * new file already existing. */
-                    g_object_unref (tmp_file);
-                    g_clear_error (error);
-                    goto out;
-                }
-            }
-        }
-        else
-        {
-            /* Error moving file. */
-            goto err;
-        }
-    }
-
-out:
-    g_object_unref (file_old);
-    g_object_unref (file_new);
-    g_assert (error == NULL || *error == NULL);
-    return TRUE;
-
-err:
-    g_object_unref (file_old);
-    g_object_unref (file_new);
-    g_assert (error == NULL || *error != NULL);
-    return FALSE;
-}
-
 /*
  * Write tag of the ETFile
  * Return TRUE => OK
@@ -1004,18 +873,17 @@ Read_Directory (const gchar *path_real)
     for (l = FileList; l != NULL && !Main_Stop_Button_Pressed;
          l = g_list_next (l))
     {
-        gchar *filename_real = l->data; /* Contains real filenames. */
+        GFile *file = l->data;
+        gchar *filename_real = g_file_get_path (file);
         gchar *filename_utf8 = filename_to_display(filename_real);
 
         msg = g_strdup_printf (_("File: ‘%s’"), filename_utf8);
         et_application_window_status_bar_message (window, msg, FALSE);
         g_free(msg);
         g_free(filename_utf8);
+        g_free (filename_real);
 
-        /* Warning: Do not free filename_real because ET_Add_File.. uses it for
-         * internal structures. */
-        ETCore->ETFileList = et_file_list_add (ETCore->ETFileList,
-                                               filename_real);
+        ETCore->ETFileList = et_file_list_add (ETCore->ETFileList, file);
 
         /* Update the progress bar. */
         fraction = (++progress_bar_index) / (double) nbrfile;
@@ -1027,8 +895,7 @@ Read_Directory (const gchar *path_real)
             gtk_main_iteration();
     }
 
-    /* Just free the list, not the data. */
-    g_list_free (FileList);
+    g_list_free_full (FileList, g_object_unref);
     et_application_window_progress_set_text (window, "");
 
     /* Close window to quit recursion */
@@ -1172,12 +1039,10 @@ read_directory_recursively (GList *file_list, GFileEnumerator *dir_enumerator,
             else if (type == G_FILE_TYPE_REGULAR &&
                      et_file_is_supported (file_name))
             {
+                /* TODO: Use g_file_enumerator_get_child(). */
                 GFile *file = g_file_get_child (g_file_enumerator_get_container (dir_enumerator),
                                                 file_name);
-                gchar *file_path = g_file_get_path (file);
-                /*Do not free this file_path, it will be used by g_list*/
-                file_list = g_list_append (file_list, file_path);
-                g_object_unref (file);
+                file_list = g_list_append (file_list, file);
             }
 
             // Just to not block X events
