@@ -22,6 +22,7 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+#include <locale.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/stat.h>
@@ -196,7 +197,7 @@ et_core_read_file_info (GFile *file,
  */
 GList *
 et_file_list_add (GList *file_list,
-                  gchar *filename)
+                  GFile *file)
 {
     GList *result;
     const ET_File_Description *description;
@@ -207,21 +208,21 @@ et_file_list_add (GList *file_list,
     gchar        *ETFileExtension;
     guint         ETFileKey;
     guint         undo_key;
-    GFile *file;
     GFileInfo *fileinfo;
-    gchar        *filename_utf8 = filename_to_display(filename);
+    gchar *filename;
+    gchar *filename_utf8;
     const gchar  *locale_lc_ctype = getenv("LC_CTYPE");
     GError *error = NULL;
     gboolean success;
 
-    g_return_val_if_fail (filename != NULL, file_list);
-
-    file = g_file_new_for_path (filename);
+    g_return_val_if_fail (file != NULL, file_list);
 
     /* Primary Key for this file */
     ETFileKey = ET_File_Key_New();
 
     /* Get description of the file */
+    filename = g_file_get_path (file);
+    filename_utf8 = filename_to_display (filename);
     description = ET_Get_File_Description (filename);
 
     /* Get real extension of the file (keeping the case) */
@@ -318,6 +319,24 @@ et_file_list_add (GList *file_list,
                 g_clear_error (&error);
             }
             break;
+#endif
+#ifndef ENABLE_MP3
+        case ID3_TAG:
+#endif
+#ifndef ENABLE_OGG
+        case OGG_TAG:
+#endif
+#ifndef ENABLE_FLAC
+        case FLAC_TAG:
+#endif
+#ifndef ENABLE_MP4
+        case MP4_TAG:
+#endif
+#ifndef ENABLE_WAVPACK
+        case WAVPACK_TAG:
+#endif
+#ifndef ENABLE_OPUS
+        case OPUS_TAG:
 #endif
         case UNKNOWN_TAG:
         default:
@@ -385,6 +404,28 @@ et_file_list_add (GList *file_list,
             break;
 #endif
         case OFR_FILE:
+#if !defined ENABLE_MP3 && !defined ENABLE_ID3LIB
+        case MP3_FILE:
+        case MP2_FILE:
+#endif
+#ifndef ENABLE_OGG
+        case OGG_FILE:
+#endif
+#ifndef ENABLE_SPEEX
+        case SPEEX_FILE:
+#endif
+#ifndef ENABLE_FLAC
+        case FLAC_FILE:
+#endif
+#ifndef ENABLE_MP4
+        case MP4_FILE:
+#endif
+#ifndef ENABLE_WAVPACK
+        case WAVPACK_FILE:
+#endif
+#ifndef ENABLE_OPUS
+        case OPUS_FILE:
+#endif
         case UNKNOWN_FILE:
         default:
             /* FIXME: Translatable string. */
@@ -411,7 +452,6 @@ et_file_list_add (GList *file_list,
      * before saving */
     fileinfo = g_file_query_info (file, G_FILE_ATTRIBUTE_TIME_MODIFIED,
                                   G_FILE_QUERY_INFO_NONE, NULL, NULL);
-    g_object_unref (file);
 
     /* Attach all data defined above to this ETFile item */
     ETFile = ET_File_Item_New();
@@ -478,6 +518,7 @@ et_file_list_add (GList *file_list,
 
     //ET_Debug_Print_File_List(ETCore->ETFileList,__FILE__,__LINE__,__FUNCTION__);
 
+    g_free (filename);
     g_free (filename_utf8);
 
     return result;
@@ -779,7 +820,7 @@ ET_Remove_File_From_File_List (ET_File *ETFile)
 
     // Find the ETFileList containing the ETFile item
     ETFileDisplayedList = g_list_find(g_list_first(ETCore->ETFileDisplayedList),ETFile);
-    ETFileList          = g_list_find(g_list_first(ETCore->ETFileList),ETFile);
+    ETFileList = g_list_find (ETCore->ETFileList, ETFile);
 
     // Note : this ETFileList must be used only for ETCore->ETFileDisplayedList, and not ETCore->ETFileDisplayed
     if (ETCore->ETFileDisplayedList == ETFileDisplayedList)
@@ -801,8 +842,7 @@ ET_Remove_File_From_File_List (ET_File *ETFile)
     }
 
     /* Remove the file from the ETFileList list. */
-    ETCore->ETFileList = g_list_remove (g_list_first (ETCore->ETFileList),
-                                        ETFileList);
+    ETCore->ETFileList = g_list_remove (ETCore->ETFileList, ETFileList);
 
     // Remove the file from the ETArtistAlbumList list
     ET_Remove_File_From_Artist_Album_List(ETFile);
