@@ -1,5 +1,5 @@
 /* EasyTAG - Tag editor for audio files
- * Copyright (C) 2013-2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2013-2015  David King <amigadave@amigadave.com>
  * Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -125,6 +125,7 @@ on_default_path_changed (GSettings *settings,
     g_variant_unref (default_path);
 }
 
+#ifdef ENABLE_ID3LIB
 static gboolean
 et_preferences_id3v2_version_get (GValue *value,
                                   GVariant *variant,
@@ -153,6 +154,7 @@ et_preferences_id3v2_version_set (const GValue *value,
 
     return id3v24;
 }
+#endif /* ENABLE_ID3LIB */
 
 static gboolean
 et_preferences_id3v2_unicode_charset_get (GValue *value,
@@ -217,7 +219,6 @@ create_preferences_dialog (EtPreferencesDialog *self)
     GtkWidget *ChangedFilesDisplayedToBold;
     GtkWidget *SortingFileCaseSensitive;
     GtkWidget *ShowLogView;
-    GtkWidget *LogMaxLinesSpinButton;
     GtkWidget *ReplaceIllegalCharactersInFilename;
     GtkWidget *PreserveModificationTime;
     GtkWidget *UpdateParentDirectoryModificationTime;
@@ -270,7 +271,6 @@ create_preferences_dialog (EtPreferencesDialog *self)
     GtkWidget *CddbProxyUserPassword;
     GtkWidget *CddbFollowFile;
     GtkWidget *CddbUseDLM;
-    GtkWidget *ConfirmBeforeExit;
     GtkWidget *ConfirmWriteTag;
     GtkWidget *ConfirmRenameFile;
     GtkWidget *ConfirmDeleteFile;
@@ -373,13 +373,7 @@ create_preferences_dialog (EtPreferencesDialog *self)
     g_settings_bind (MainSettings, "log-show", ShowLogView, "active",
                      G_SETTINGS_BIND_DEFAULT);
    
-    /* Max number of lines. */
-    LogMaxLinesSpinButton = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                                "log_lines_button"));
-    g_settings_bind (MainSettings, "log-lines", LogMaxLinesSpinButton,
-                     "value", G_SETTINGS_BIND_DEFAULT);
-
-    /* Show header informantion. */
+    /* Show header information. */
     ShowHeaderInfos = GTK_WIDGET (gtk_builder_get_object (builder,
                                                           "header_show_check"));
     g_settings_bind (MainSettings, "file-show-header", ShowHeaderInfos,
@@ -944,11 +938,6 @@ create_preferences_dialog (EtPreferencesDialog *self)
     /*
      * Confirmation
      */
-    ConfirmBeforeExit = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                            "confirm_quit_check"));
-    g_settings_bind (MainSettings, "confirm-quit", ConfirmBeforeExit, "active",
-                     G_SETTINGS_BIND_DEFAULT);
-
     ConfirmWriteTag = GTK_WIDGET (gtk_builder_get_object (builder,
                                                           "confirm_write_check"));
     g_settings_bind (MainSettings, "confirm-write-tags", ConfirmWriteTag,
