@@ -256,7 +256,9 @@ Add_Row_To_Search_Result_List (EtSearchDialog *self,
     {
         if (case_sensitive)
         {
-            if ( SearchResultList_Text[column] && strlen(string_to_search) && strstr(SearchResultList_Text[column],string_to_search) )
+            if (SearchResultList_Text[column]
+                && !et_str_empty (string_to_search)
+                && strstr (SearchResultList_Text[column], string_to_search))
             {
                 if (g_settings_get_boolean (MainSettings, "file-changed-bold"))
                 {
@@ -282,7 +284,8 @@ Add_Row_To_Search_Result_List (EtSearchDialog *self,
 
             list_text = g_utf8_casefold(SearchResultList_Text[column], -1);
 
-            if ( list_text && strlen(string_to_search2) && strstr(list_text,string_to_search2) )
+            if (list_text && !et_str_empty (string_to_search2)
+                && strstr (list_text, string_to_search2))
             {
                 if (g_settings_get_boolean (MainSettings, "file-changed-bold"))
                 {
@@ -406,7 +409,7 @@ Search_File (GtkWidget *search_button, gpointer user_data)
     gtk_list_store_clear(priv->search_results_model);
     gtk_statusbar_push(GTK_STATUSBAR(priv->status_bar),priv->status_bar_context,"");
 
-    for (l = g_list_first (ETCore->ETFileList); l != NULL; l = g_list_next (l))
+    for (l = ETCore->ETFileList; l != NULL; l = g_list_next (l))
     {
         ETFile = (ET_File *)l->data;
 
